@@ -91,6 +91,7 @@ import Control.Applicative (Applicative (..))
 import Control.Exception (Exception)
 import qualified Control.Exception as E (catch)
 import Control.Monad (liftM, liftM2, ap)
+import Control.Monad.Fail(MonadFail(..))
 import Control.Monad.Error.Class(MonadError(..))
 import Control.Monad.Reader.Class(MonadReader(..))
 import Control.Monad.RWS.Class(MonadRWS())
@@ -149,6 +150,10 @@ instance Monad (ConduitT i o m) where
     return = pure
     ConduitT f >>= g = ConduitT $ \h -> f $ \a -> unConduitT (g a) h
 
+-- | @since 1.3.1
+instance MonadFail m => MonadFail (ConduitT i o m) where
+    fail = lift . Control.Monad.Fail.fail
+
 instance MonadThrow m => MonadThrow (ConduitT i o m) where
     throwM = lift . throwM
 
@@ -714,7 +719,7 @@ connect :: Monad m
         -> m r
 connect = ($$)
 
--- | Named function synonym for '.|'.
+-- | Named function synonym for '.|'
 --
 -- Equivalent to '.|' and '=$='. However, the latter is
 -- deprecated and will be removed in a future version.
